summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-07 20:20:54 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-07 20:20:54 -0600
commit77b949ed8f72e66e6c8df55d7365c276e0e128f4 (patch)
treeb831da1654087ff8b097632ee1f37d734d98bc85
parentfb539e074a48d23dc160dc10a1817d04406a0223 (diff)
downloadyakuake-77b949ed8f72e66e6c8df55d7365c276e0e128f4.tar.gz
yakuake-77b949ed8f72e66e6c8df55d7365c276e0e128f4.zip
Rename kwin to twin (part 1 of 2)
-rw-r--r--yakuake/src/main_window.cpp6
-rw-r--r--yakuake/src/main_window.h4
2 files changed, 5 insertions, 5 deletions
diff --git a/yakuake/src/main_window.h b/yakuake/src/main_window.h
index ec00461..4674347 100644
--- a/yakuake/src/main_window.h
+++ b/yakuake/src/main_window.h
@@ -28,14 +28,14 @@
#include <tqapplication.h>
#include <tqwidgetstack.h>
-#include <kwin.h>
+#include <twin.h>
#include <kaction.h>
#include <kconfig.h>
#include <klocale.h>
#include <dcopclient.h>
#include <kkeydialog.h>
#include <kpopupmenu.h>
-#include <kwinmodule.h>
+#include <twinmodule.h>
#include <kmainwindow.h>
#include <kapplication.h>
#include <kglobalaccel.h>
diff --git a/yakuake/src/main_window.cpp b/yakuake/src/main_window.cpp
index 7f3a8b8..5253b54 100644
--- a/yakuake/src/main_window.cpp
+++ b/yakuake/src/main_window.cpp
@@ -27,7 +27,7 @@
#include <kmessagebox.h>
#include <kconfigdialog.h>
#include <kiconloader.h>
-#include <kwin.h>
+#include <twin.h>
#include <dcopref.h>
MainWindow::MainWindow(TQWidget * parent, const char * name) :
@@ -909,7 +909,7 @@ void MainWindow::slotToggleState()
if (timer.isActive())
return;
- KWinModule kwin(TQT_TQOBJECT(this));
+ KWinModule twin(TQT_TQOBJECT(this));
if (state)
{
@@ -1058,7 +1058,7 @@ void MainWindow::moveEvent(TQMoveEvent* e)
// mouse cursor is on, detect whether the screen number has
// changed on this move event and update the internal set-
// ting. Makes it play nice with the move-window-to-screen
// kwin shortcuts found in Lubos' Xinerama Improvements patch-
// set.
if (Settings::screen()
@@ -1058,7 +1058,7 @@ void MainWindow::moveEvent(TQMoveEvent* e)
// changed on this move event and update the internal set-
// ting. Makes it play nice with the move-window-to-screen
- // kwin shortcuts found in Lubos' Xinerama Improvements patch-
+ // twin shortcuts found in Lubos' Xinerama Improvements patch-
// set.
if (Settings::screen()